@@ -99,8 +99,8 @@ class BenchmarkPool(futurist.ProcessPoolExecutor):
         LOG.info(
             "%d/%d, "
             "total: %.2f seconds, "
-            "rate: %.2f %s/second"
-            % (done, self.times, runtime, rate, verb))
+            "rate: %.2f %s/second",
+            done, self.times, runtime, rate, verb)
 
     def wait_job(self, verb, futures):
         while self.statistics.executed != self.times:
@@ -117,7 +117,7 @@ class BenchmarkPool(futurist.ProcessPoolExecutor):
                 results.append(result)
                 latencies.append(latency)
             except Exception as e:
-                LOG.error("Error with %s metric: %s" % (verb, e))
+                LOG.error("Error with %s metric: %s", (verb, e))
         latencies = sorted(latencies)
         return results, runtime, {
             'client workers': self._max_workers,
@@ -320,8 +320,8 @@ class CliBenchmarkMeasuresAdd(CliBenchmarkBase,
                     break
                 else:
                     LOG.info(
-                        "Remaining measures to be processed: %d"
-                        % remaining)
+                        "Remaining measures to be processed: %d",
+                        remaining)
                 time.sleep(1)
 
         return self.dict2columns(stats)
