@@ -11,7 +11,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import iso8601
 import json
 import logging
 import sys
@@ -20,6 +19,8 @@ from cliff import command
 from cliff import lister
 from cliff import show
 
+import iso8601
+
 from gnocchiclient import utils
 
 
@@ -35,7 +36,7 @@ class CliMetricWithResourceID(command.Command):
 
 
 class CliMetricList(lister.Lister):
-    """List metrics"""
+    """List metrics."""
 
     COLS = ('id', 'archive_policy/name', 'name', 'unit', 'resource_id')
 
@@ -61,17 +62,8 @@ class CliMetricList(lister.Lister):
         return utils.list2cols(self.COLS, metrics)
 
 
-class DeprecatedCliMetricList(CliMetricList):
-    """Deprecated: List metrics"""
-
-    def take_action(self, parsed_args):
-        LOG_DEP.warning('This command has been deprecated. '
-                        'Please use "metric list" instead.')
-        return super(DeprecatedCliMetricList, self).take_action(parsed_args)
-
-
 class CliMetricShow(CliMetricWithResourceID, show.ShowOne):
-    """Show a metric"""
+    """Show a metric."""
 
     def get_parser(self, prog_name):
         parser = super(CliMetricShow, self).get_parser(prog_name)
@@ -91,15 +83,6 @@ class CliMetricShow(CliMetricWithResourceID, show.ShowOne):
         return self.dict2columns(metric)
 
 
-class DeprecatedCliMetricShow(CliMetricShow):
-    """Deprecated: Show a metric"""
-
-    def take_action(self, parsed_args):
-        LOG_DEP.warning('This command has been deprecated. '
-                        'Please use "metric show" instead.')
-        return super(DeprecatedCliMetricShow, self).take_action(parsed_args)
-
-
 class CliMetricCreateBase(show.ShowOne, CliMetricWithResourceID):
     def get_parser(self, prog_name):
         parser = super(CliMetricCreateBase, self).get_parser(prog_name)
@@ -110,7 +93,7 @@ class CliMetricCreateBase(show.ShowOne, CliMetricWithResourceID):
 
 
 class CliMetricCreate(CliMetricCreateBase):
-    """Create a metric"""
+    """Create a metric."""
 
     def get_parser(self, prog_name):
         parser = super(CliMetricCreate, self).get_parser(prog_name)
@@ -137,17 +120,8 @@ class CliMetricCreate(CliMetricCreateBase):
         return self.dict2columns(metric)
 
 
-class DeprecatedCliMetricCreate(CliMetricCreate):
-    """Deprecated: Create a metric"""
-
-    def take_action(self, parsed_args):
-        LOG_DEP.warning('This command has been deprecated. '
-                        'Please use "metric create" instead.')
-        return super(DeprecatedCliMetricCreate, self).take_action(parsed_args)
-
-
 class CliMetricDelete(CliMetricWithResourceID):
-    """Delete a metric"""
+    """Delete a metric."""
 
     def get_parser(self, prog_name):
         parser = super(CliMetricDelete, self).get_parser(prog_name)
@@ -161,15 +135,6 @@ class CliMetricDelete(CliMetricWithResourceID):
                 metric=metric, resource_id=parsed_args.resource_id)
 
 
-class DeprecatedCliMetricDelete(CliMetricDelete):
-    """Deprecated: Delete a metric"""
-
-    def take_action(self, parsed_args):
-        LOG_DEP.warning('This command has been deprecated. '
-                        'Please use "metric delete" instead.')
-        return super(DeprecatedCliMetricDelete, self).take_action(parsed_args)
-
-
 class CliMeasuresReturn(lister.Lister):
     def get_parser(self, prog_name):
         parser = super(CliMeasuresReturn, self).get_parser(prog_name)
@@ -181,7 +146,8 @@ class CliMeasuresReturn(lister.Lister):
     @staticmethod
     def format_measures_with_tz(parsed_args, measures):
         if parsed_args.utc:
-            t = lambda x: x
+            def t(x):
+                return x
         else:
             t = utils.dt_to_localtz
         return [(t(dt).isoformat(), g, v) for dt, g, v in measures]
@@ -189,7 +155,7 @@ class CliMeasuresReturn(lister.Lister):
 
 class CliMeasuresShow(CliMetricWithResourceID, CliMeasuresReturn,
                       lister.Lister):
-    """Get measurements of a metric"""
+    """Get measurements of a metric."""
 
     COLS = ('timestamp', 'granularity', 'value')
 
@@ -236,7 +202,7 @@ class CliMeasuresAddBase(CliMetricWithResourceID):
 
 
 class CliMeasuresAdd(CliMeasuresAddBase):
-    """Add measurements to a metric"""
+    """Add measurements to a metric."""
 
     def measure(self, measure):
         timestamp, __, value = measure.rpartition("@")
@@ -301,7 +267,7 @@ class CliResourcesMetricsMeasuresBatch(CliMeasuresBatch):
 
 
 class CliMeasuresAggregation(CliMeasuresReturn):
-    """Get measurements of aggregated metrics"""
+    """Get measurements of aggregated metrics."""
 
     COLS = ('timestamp', 'granularity', 'value')
 
